@@ -17,7 +17,7 @@ from .structures import Intermediate, Resource
 def get_hash(file: Path | BytesIO | bytes, hash_type: str = "sha256") -> str:
 
     if isinstance(file, Path): data = file.read_bytes()
-    elif isinstance(file, BytesIO): data = file.read()
+    elif isinstance(file, BytesIO): data = file.read(); file.seek(0)
     elif isinstance(file, bytes): data = file
     else: raise TypeError("Incorrect file type!")
         
@@ -203,12 +203,13 @@ async def resolve_conflicts(session: CachedSession, intermediate: Intermediate)
 
     for resource in intermediate.resources:
         if provider := resource.providers.get('Other'):
-            cloud_file = next(file for url, file in files if url == provider.url)
+            cloud_file = BytesIO(next(file for url, file in files if url == provider.url))
             sha1, sha256, sha512 = get_hashes(cloud_file, "sha1", "sha256", "sha512")
+            size = cloud_file.tell()
             if "Modrinth" in resource.providers:
                 if resource.file.hash.sha1 != sha1 \
                 or resource.file.hash.sha512 != sha512 \
-                or resource.file.size != (size := len(cloud_file)):
+                or resource.file.size != size:
                     resource.providers.pop("Other")
             else: 
                 resource.file.size = size
